@@ -28,6 +28,12 @@ Backtrace::Backtrace () noexcept {
     buffer.resize(depth);
 }
 
+#else
+
+Backtrace::Backtrace () noexcept {}
+
+#endif
+
 Backtrace::~Backtrace() {}
 
 iptr<BacktraceInfo> Backtrace::get_backtrace_info() const noexcept {
@@ -35,14 +41,6 @@ iptr<BacktraceInfo> Backtrace::get_backtrace_info() const noexcept {
     return iptr<BacktraceInfo>();
 }
 
-#else
-  
-backtrace::backtrace () noexcept {}
-string backtrace::get_trace_string () const { return {}; }
-
-#endif
-
-
 exception::exception () noexcept {}
 
 exception::exception (const string& whats) noexcept : _whats(whats) {}
